*******************
Enumeration Classes
*******************

.. module:: yangson.enumerations
   :synopsis: Enumeration classes

.. autoclass:: ContentType
   :members:

.. autoclass:: ValidationScope
   :members:

.. autoclass:: DefaultDeny
   :members:

.. autoclass:: Axis
   :members:

.. autoclass:: MultiplicativeOp
   :members:
